Rev 4578: Adjust WorkingTree4 specific test to deal with iter_changes reporting required directories. in http://bazaar.launchpad.net/~lifeless/bzr/iter-changes-partial-parents

Robert Collins robertc at robertcollins.net
Tue Aug 4 02:17:16 BST 2009


At http://bazaar.launchpad.net/~lifeless/bzr/iter-changes-partial-parents

------------------------------------------------------------
revno: 4578
revision-id: robertc at robertcollins.net-20090804011713-qtkqq7b22fpsxzae
parent: robertc at robertcollins.net-20090804011500-qu3ksvuj8xhrl3w8
committer: Robert Collins <robertc at robertcollins.net>
branch nick: iter-changes-partial-parents
timestamp: Tue 2009-08-04 11:17:13 +1000
message:
  Adjust WorkingTree4 specific test to deal with iter_changes reporting required directories.
=== modified file 'bzrlib/tests/test_workingtree_4.py'
--- a/bzrlib/tests/test_workingtree_4.py	2009-07-01 07:26:30 +0000
+++ b/bzrlib/tests/test_workingtree_4.py	2009-08-04 01:17:13 +0000
@@ -490,7 +490,8 @@
         subtree = self.make_branch_and_tree('dir')
         # the most primitive operation: kind
         self.assertEqual('directory', tree.kind('dir-id'))
         # a diff against the basis should give us a directory
         tree.lock_read()
         expected = [('dir-id',
             (None, u'dir'),
@@ -499,7 +500,9 @@
             (None, 'root'),
             (None, u'dir'),
             (None, 'directory'),
-            (None, False))]
+            (None, False)),
+            ('root', (None, u''), True, (False, True), (None, None),
+            (None, u''), (None, 'directory'), (None, 0))]
         self.assertEqual(expected, list(tree.iter_changes(tree.basis_tree(),
             specific_files=['dir'])))
         tree.unlock()
@@ -490,7 +490,8 @@
         # the most primitive operation: kind
         self.assertEqual('directory', tree.kind('dir-id'))
-        # a diff against the basis should give us a directory
+        # a diff against the basis should give us a directory and the root (as
+        # the root is new too).
         tree.lock_read()
         expected = [('dir-id',




More information about the bazaar-commits mailing list